@@ -27,17 +27,15 @@ use lib "$Bin/../../lib";
 use Google::Ads::GoogleAds::Client;
 use Google::Ads::GoogleAds::Utils::GoogleAdsHelper;
 use Google::Ads::GoogleAds::Utils::SearchGoogleAdsIterator;
-use Google::Ads::GoogleAds::V16::Enums::ServedAssetFieldTypeEnum
+use Google::Ads::GoogleAds::V17::Enums::ServedAssetFieldTypeEnum
   qw(UNSPECIFIED);
 use
-  Google::Ads::GoogleAds::V16::Services::GoogleAdsService::SearchGoogleAdsRequest;
+  Google::Ads::GoogleAds::V17::Services::GoogleAdsService::SearchGoogleAdsRequest;
 
 use Getopt::Long qw(:config auto_help);
 use Pod::Usage;
 use Cwd qw(abs_path);
 
-use constant PAGE_SIZE => 1000;
-
 # The following parameter(s) should be provided to run the example. You can
 # either specify these by changing the INSERT_XXX_ID_HERE values below, or on
 # the command line.
@@ -68,11 +66,10 @@ sub get_responsive_search_ads {
   # Create a search Google Ads request that will retrieve all responsive search
   # ads using pages of the specified page size.
   my $search_request =
-    Google::Ads::GoogleAds::V16::Services::GoogleAdsService::SearchGoogleAdsRequest
+    Google::Ads::GoogleAds::V17::Services::GoogleAdsService::SearchGoogleAdsRequest
     ->new({
       customerId => $customer_id,
-      query      => $search_query,
-      pageSize   => PAGE_SIZE
+      query      => $search_query
     });
 
   # Get the GoogleAdsService.
