@@ -34,28 +34,26 @@ use lib "$Bin/../../lib";
 use Google::Ads::GoogleAds::Client;
 use Google::Ads::GoogleAds::Utils::GoogleAdsHelper;
 use Google::Ads::GoogleAds::Utils::SearchGoogleAdsIterator;
-use Google::Ads::GoogleAds::V16::Resources::AdGroupCriterion;
-use Google::Ads::GoogleAds::V16::Common::ListingGroupInfo;
-use Google::Ads::GoogleAds::V16::Common::ListingDimensionInfo;
-use Google::Ads::GoogleAds::V16::Common::ProductConditionInfo;
-use Google::Ads::GoogleAds::V16::Common::ProductBrandInfo;
-use Google::Ads::GoogleAds::V16::Enums::ListingGroupTypeEnum
+use Google::Ads::GoogleAds::V17::Resources::AdGroupCriterion;
+use Google::Ads::GoogleAds::V17::Common::ListingGroupInfo;
+use Google::Ads::GoogleAds::V17::Common::ListingDimensionInfo;
+use Google::Ads::GoogleAds::V17::Common::ProductConditionInfo;
+use Google::Ads::GoogleAds::V17::Common::ProductBrandInfo;
+use Google::Ads::GoogleAds::V17::Enums::ListingGroupTypeEnum
   qw(SUBDIVISION UNIT);
-use Google::Ads::GoogleAds::V16::Enums::AdGroupCriterionStatusEnum qw(ENABLED);
-use Google::Ads::GoogleAds::V16::Enums::ProductConditionEnum       qw(NEW USED);
+use Google::Ads::GoogleAds::V17::Enums::AdGroupCriterionStatusEnum qw(ENABLED);
+use Google::Ads::GoogleAds::V17::Enums::ProductConditionEnum       qw(NEW USED);
 use
-  Google::Ads::GoogleAds::V16::Services::AdGroupCriterionService::AdGroupCriterionOperation;
+  Google::Ads::GoogleAds::V17::Services::AdGroupCriterionService::AdGroupCriterionOperation;
 use
-  Google::Ads::GoogleAds::V16::Services::GoogleAdsService::SearchGoogleAdsRequest;
-use Google::Ads::GoogleAds::V16::Utils::ResourceNames;
+  Google::Ads::GoogleAds::V17::Services::GoogleAdsService::SearchGoogleAdsRequest;
+use Google::Ads::GoogleAds::V17::Utils::ResourceNames;
 
 use Getopt::Long qw(:config auto_help);
 use Pod::Usage;
 use Cwd          qw(abs_path);
 use Data::Uniqid qw(uniqid);
 
-use constant PAGE_SIZE => 1000;
-
 # The following parameter(s) should be provided to run the example. You can
 # either specify these by changing the INSERT_XXX_ID_HERE values below, or on
 # the command line.
@@ -92,7 +90,7 @@ sub add_shopping_product_listing_group_tree {
   my $ad_group_criterion_root_resource_name =
     $ad_group_criterion_root->{resourceName};
   push @$operations,
-    Google::Ads::GoogleAds::V16::Services::AdGroupCriterionService::AdGroupCriterionOperation
+    Google::Ads::GoogleAds::V17::Services::AdGroupCriterionService::AdGroupCriterionOperation
     ->new({
       create => $ad_group_criterion_root
     });
@@ -106,16 +104,16 @@ sub add_shopping_product_listing_group_tree {
     $customer_id,
     $ad_group_id,
     $ad_group_criterion_root_resource_name,
-    Google::Ads::GoogleAds::V16::Common::ListingDimensionInfo->new({
+    Google::Ads::GoogleAds::V17::Common::ListingDimensionInfo->new({
         productCondition =>
-          Google::Ads::GoogleAds::V16::Common::ProductConditionInfo->new({
+          Google::Ads::GoogleAds::V17::Common::ProductConditionInfo->new({
             condition => NEW
           })}
     ),
     200000
   );
   push @$operations,
-    Google::Ads::GoogleAds::V16::Services::AdGroupCriterionService::AdGroupCriterionOperation
+    Google::Ads::GoogleAds::V17::Services::AdGroupCriterionService::AdGroupCriterionOperation
     ->new({
       create => $ad_group_criterion_condition_new
     });
@@ -127,16 +125,16 @@ sub add_shopping_product_listing_group_tree {
     $customer_id,
     $ad_group_id,
     $ad_group_criterion_root_resource_name,
-    Google::Ads::GoogleAds::V16::Common::ListingDimensionInfo->new({
+    Google::Ads::GoogleAds::V17::Common::ListingDimensionInfo->new({
         productCondition =>
-          Google::Ads::GoogleAds::V16::Common::ProductConditionInfo->new({
+          Google::Ads::GoogleAds::V17::Common::ProductConditionInfo->new({
             condition => USED
           })}
     ),
     100000
   );
   push @$operations,
-    Google::Ads::GoogleAds::V16::Services::AdGroupCriterionService::AdGroupCriterionOperation
+    Google::Ads::GoogleAds::V17::Services::AdGroupCriterionService::AdGroupCriterionOperation
     ->new({
       create => $ad_group_criterion_condition_used
     });
@@ -147,13 +145,13 @@ sub add_shopping_product_listing_group_tree {
     $customer_id,
     $ad_group_id,
     $ad_group_criterion_root_resource_name,
-    Google::Ads::GoogleAds::V16::Common::ListingDimensionInfo->new({
+    Google::Ads::GoogleAds::V17::Common::ListingDimensionInfo->new({
         # All sibling nodes must have the same dimension type, even if they
         # don't contain a bid.
         productCondition =>
-          Google::Ads::GoogleAds::V16::Common::ProductConditionInfo->new()}));
+          Google::Ads::GoogleAds::V17::Common::ProductConditionInfo->new()}));
   push @$operations,
-    Google::Ads::GoogleAds::V16::Services::AdGroupCriterionService::AdGroupCriterionOperation
+    Google::Ads::GoogleAds::V17::Services::AdGroupCriterionService::AdGroupCriterionOperation
     ->new({
       create => $ad_group_criterion_condition_other
     });
@@ -174,15 +172,15 @@ sub add_shopping_product_listing_group_tree {
     $customer_id,
     $ad_group_id,
     $ad_group_criterion_condition_other_resource_name,
-    Google::Ads::GoogleAds::V16::Common::ListingDimensionInfo->new({
+    Google::Ads::GoogleAds::V17::Common::ListingDimensionInfo->new({
         productBrand =>
-          Google::Ads::GoogleAds::V16::Common::ProductBrandInfo->new(
+          Google::Ads::GoogleAds::V17::Common::ProductBrandInfo->new(
           {value => "CoolBrand"})}
     ),
     900000
   );
   push @$operations,
-    Google::Ads::GoogleAds::V16::Services::AdGroupCriterionService::AdGroupCriterionOperation
+    Google::Ads::GoogleAds::V17::Services::AdGroupCriterionService::AdGroupCriterionOperation
     ->new({
       create => $ad_group_criterion_brand_cool_brand
     });
@@ -194,15 +192,15 @@ sub add_shopping_product_listing_group_tree {
     $customer_id,
     $ad_group_id,
     $ad_group_criterion_condition_other_resource_name,
-    Google::Ads::GoogleAds::V16::Common::ListingDimensionInfo->new({
+    Google::Ads::GoogleAds::V17::Common::ListingDimensionInfo->new({
         productBrand =>
-          Google::Ads::GoogleAds::V16::Common::ProductBrandInfo->new(
+          Google::Ads::GoogleAds::V17::Common::ProductBrandInfo->new(
           {value => "CheapBrand"})}
     ),
     10000
   );
   push @$operations,
-    Google::Ads::GoogleAds::V16::Services::AdGroupCriterionService::AdGroupCriterionOperation
+    Google::Ads::GoogleAds::V17::Services::AdGroupCriterionService::AdGroupCriterionOperation
     ->new({
       create => $ad_group_criterion_brand_cheap_brand
     });
@@ -213,14 +211,14 @@ sub add_shopping_product_listing_group_tree {
     $customer_id,
     $ad_group_id,
     $ad_group_criterion_condition_other_resource_name,
-    Google::Ads::GoogleAds::V16::Common::ListingDimensionInfo->new({
+    Google::Ads::GoogleAds::V17::Common::ListingDimensionInfo->new({
         productBrand =>
-          Google::Ads::GoogleAds::V16::Common::ProductBrandInfo->new()}
+          Google::Ads::GoogleAds::V17::Common::ProductBrandInfo->new()}
     ),
     50000
   );
   push @$operations,
-    Google::Ads::GoogleAds::V16::Services::AdGroupCriterionService::AdGroupCriterionOperation
+    Google::Ads::GoogleAds::V17::Services::AdGroupCriterionService::AdGroupCriterionOperation
     ->new({
       create => $ad_group_criterion_brand_other_brand
     });
@@ -259,11 +257,10 @@ sub remove_listing_group_tree {
   # where the parent ad group criterion is NULL (and hence the root node in
   # the tree) for a given ad group id.
   my $search_request =
-    Google::Ads::GoogleAds::V16::Services::GoogleAdsService::SearchGoogleAdsRequest
+    Google::Ads::GoogleAds::V17::Services::GoogleAdsService::SearchGoogleAdsRequest
     ->new({
       customerId => $customer_id,
-      query      => $search_query,
-      pageSize   => PAGE_SIZE
+      query      => $search_query
     });
 
   # Get the GoogleAdsService.
@@ -284,7 +281,7 @@ sub remove_listing_group_tree {
 
     # Create an ad group criterion operation.
     my $ad_group_criterion_operation =
-      Google::Ads::GoogleAds::V16::Services::AdGroupCriterionService::AdGroupCriterionOperation
+      Google::Ads::GoogleAds::V17::Services::AdGroupCriterionService::AdGroupCriterionOperation
       ->new({
         remove => $ad_group_criterion->{resourceName}});
 
@@ -313,7 +310,7 @@ sub create_listing_group_subdivision {
     = @_;
 
   my $listing_group_info =
-    Google::Ads::GoogleAds::V16::Common::ListingGroupInfo->new({
+    Google::Ads::GoogleAds::V17::Common::ListingGroupInfo->new({
       # Set the type as a SUBDIVISION, which will allow the node to be the
       # parent of another sub-tree.
       'type' => SUBDIVISION
@@ -332,11 +329,11 @@ sub create_listing_group_subdivision {
   }
 
   my $ad_group_criterion =
-    Google::Ads::GoogleAds::V16::Resources::AdGroupCriterion->new({
+    Google::Ads::GoogleAds::V17::Resources::AdGroupCriterion->new({
       # The resource name the criterion will be created with. This will define
       # the ID for the ad group criterion.
       resourceName =>
-        Google::Ads::GoogleAds::V16::Utils::ResourceNames::ad_group_criterion(
+        Google::Ads::GoogleAds::V17::Utils::ResourceNames::ad_group_criterion(
         $customer_id, $ad_group_id, next_id()
         ),
       status       => ENABLED,
@@ -361,13 +358,13 @@ sub create_listing_group_unit_biddable {
   # the listing group for non-root nodes.
   # This example demonstrates method (1).
   my $ad_group_criterion =
-    Google::Ads::GoogleAds::V16::Resources::AdGroupCriterion->new({
-      adGroup => Google::Ads::GoogleAds::V16::Utils::ResourceNames::ad_group(
+    Google::Ads::GoogleAds::V17::Resources::AdGroupCriterion->new({
+      adGroup => Google::Ads::GoogleAds::V17::Utils::ResourceNames::ad_group(
         $customer_id, $ad_group_id
       ),
       status       => ENABLED,
       listingGroup =>
-        Google::Ads::GoogleAds::V16::Common::ListingGroupInfo->new({
+        Google::Ads::GoogleAds::V17::Common::ListingGroupInfo->new({
           # Set the type as a UNIT, which will allow the group to be biddable.
           type => UNIT,
           # Set the ad group criterion resource name for the parent listing group.
