@@ -22,7 +22,12 @@ use Google::Ads::GoogleAds::Utils::GoogleAdsHelper;
 
 sub new {
   my ($class, $args) = @_;
-  my $self = {entityId => $args->{entityId}};
+  my $self = {
+    displayName     => $args->{displayName},
+    entityId        => $args->{entityId},
+    primaryUrl      => $args->{primaryUrl},
+    rejectionReason => $args->{rejectionReason},
+    status          => $args->{status}};
 
   # Delete the unassigned fields in this object for a more concise JSON payload
   remove_unassigned_fields($self, $args);
